event_queue = []
listeners_mapping = dict()


def register_listeners(listeners):
    global listeners_mapping
    listeners_mapping = listeners


def fire_event(evt):
    global listeners_mapping
    global event_queue

    from .listener import Listener
    for k, v in listeners_mapping.items():
        if k == type(evt):
            if type(v) is list:
                for lst in v:
                    lst().handle(evt)
            elif issubclass(v, Listener):
                v().handle(evt)


def fire_all_postponed():
    global listeners_mapping
    global event_queue

    for evt in event_queue:
        fire_event(evt)

    event_queue.clear()



class Event(object):
    def __init__(self, **kwargs):
        for k, v in kwargs.items():
            setattr(self, k, v)

    def fire(self):
        from .queue import fire_event
        fire_event(self)

    def postpone(self):
        from .queue import event_queue
        if self not in event_queue:
            event_queue.append(self)



from setuptools import setup, find_packages

setup(
    name='jcevents',
    version='1.0.0',
    description='A lightweight event-driven framework for Python',
    long_description='',
    url='https://github.com/jencat42/jcevents',
    author='Your Name',
    author_email='gubenkovalik@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords='event-driven framework',
    packages=find_packages(),
    python_requires='>=3.6',
    install_requires=[],
)
